@@ -2,25 +2,24 @@
 from .. import *
 from .. import dispatch as dispatch_original
 from ..shape import dispatch_unwrap_dimensions
-from ..types import Number, NPNumeric, AGNumeric
+from ..types import AGNumeric, NPNumeric, Number
 
 dispatch = dispatch_unwrap_dimensions(dispatch_original)
 
-from plum import Union
+from typing import Union
 
 Numeric = Union[Number, NPNumeric, AGNumeric]
 
-from .generic import *
-from .shaping import *
-from .linear_algebra import *
-from .random import *
+from plum import clear_all_cache as _clear_all_cache
 
 # noinspection PyUnresolvedReferences
-from ..types import _ag_retrievables
+from .generic import *
+from .linear_algebra import *
+from .random import *
+from .shaping import *
 
-# Retrieve types.
-for retrievable in _ag_retrievables:
-    retrievable.retrieve()
+# Clear cache to make sure that all newly loaded types are available.
+_clear_all_cache()
 
 # Alias to actual module.
 sys.modules[__name__] = B
